"use strict";(self.webpackChunklcn_frontend=self.webpackChunklcn_frontend||[]).push([[942],{81942:function(e,n,t){t.r(n),t.d(n,{ProgressDialog:function(){return y}});var i,r,a=t(88962),o=t(99312),s=t(81043),c=t(33368),l=t(71650),d=t(82390),u=t(69205),h=t(70906),p=t(51565),v=(t(97393),t(7006),t(68144)),f=t(73175),k=t(29950),g=t(18394),y=(0,p.Z)([(0,f.Mo)("progress-dialog")],(function(e,n){var t,p,y=function(n){(0,u.Z)(i,n);var t=(0,h.Z)(i);function i(){var n;(0,l.Z)(this,i);for(var r=arguments.length,a=new Array(r),o=0;o<r;o++)a[o]=arguments[o];return n=t.call.apply(t,[this].concat(a)),e((0,d.Z)(n)),n}return(0,c.Z)(i)}(n);return{F:y,d:[{kind:"field",decorators:[(0,f.Cb)({attribute:!1})],key:"hass",value:void 0},{kind:"field",decorators:[(0,f.SB)()],key:"_params",value:void 0},{kind:"field",decorators:[(0,f.IO)("ha-dialog",!0)],key:"_dialog",value:void 0},{kind:"method",key:"showDialog",value:(p=(0,s.Z)((0,o.Z)().mark((function e(n){return(0,o.Z)().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:return this._params=n,e.next=3,this.updateComplete;case 3:(0,g.B)(this._dialog,"iron-resize");case 4:case"end":return e.stop()}}),e,this)}))),function(e){return p.apply(this,arguments)})},{kind:"method",key:"closeDialog",value:(t=(0,s.Z)((0,o.Z)().mark((function e(){return(0,o.Z)().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:this.close();case 1:case"end":return e.stop()}}),e,this)}))),function(){return t.apply(this,arguments)})},{kind:"method",key:"render",value:function(){var e,n;return this._params?(0,v.dy)(i||(i=(0,a.Z)(["\n      <ha-dialog open scrimClickAction escapeKeyAction @close-dialog=",">\n        <h2>","</h2>\n        <p>",'</p>\n\n        <div id="dialog-content">\n          <ha-circular-progress active></ha-circular-progress>\n        </div>\n      </ha-dialog>\n    '])),this.closeDialog,null===(e=this._params)||void 0===e?void 0:e.title,null===(n=this._params)||void 0===n?void 0:n.text):v.Ld}},{kind:"method",key:"close",value:function(){this._params=void 0}},{kind:"get",static:!0,key:"styles",value:function(){return[k.yu,(0,v.iv)(r||(r=(0,a.Z)(["\n        #dialog-content {\n          text-align: center;\n        }\n      "])))]}}]}}),v.oi)}}]);